# xpdConf
![test](https://github.com/xpdAcq/xpdConf/workflows/test/badge.svg)
[![codecov](https://codecov.io/gh/xpdAcq/xpdConf/branch/master/graph/badge.svg)](https://codecov.io/gh/xpdAcq/xpdConf)

The package to load configuration for xpdAcq. It will provide the ``glbl_dict`` for the xpdAcq.
